@@ -1,7 +1,7 @@
 #include "Model.h"
 #include "Decimate.h"
-#include "ImportAndExport/ObjImportExport.h"
-#include "ImportAndExport/AssimpImportExport.h"
+#include "ObjImportExport.h"
+#include "AssimpImportExport.h"
 
 using namespace vivid;
 using namespace std;
@@ -26,7 +26,12 @@ void CModel::ExportToObj(const string &arOutputFilePath, bool WithTexture){
     OBJExporter(*this, arOutputFilePath, WithTexture);
 }
 
-int CModel::Export(const std::string &arOutputFilePath, const std::string& arFileType){
-    return AssimpExport::AssimpExporter(*this, arFileType, arOutputFilePath);
+void CModel::Export(const std::string &arOutputFilePath, const std::string& arFileType){
+    AssimpExport::AssimpExporter(*this, arFileType, arOutputFilePath);
 }
+
+CBlobData CModel::ExportToBlob(const std::string& arFileType) {
+    return AssimpExport::AssimpExporter(*this, arFileType);
+}
+
 CModel::~CModel() = default;
\ No newline at end of file
