@@ -5,12 +5,12 @@
 #include <functional>
 #include <map>
 
-
 #include "Point.h"
 #include "Face.h"
 #include "ColorMap.h"
 #include "Material.h"
 #include "LogFile.h"
+#include "BlobData.h"
 
 namespace vivid
 {
@@ -29,20 +29,20 @@ namespace vivid
         vector<CFace> mFaces = {};
         FACE_TYPE mElementType = POLYGONS;
         std::string mLabel = "";
-        CColorMap mClm;
+        CColorMap mCmap;
         CMaterial mMaterial;
         //Constructor, Copy Constructor, Destructor
         CModelComponent(){}
         CModelComponent(const FACE_TYPE aElementType) : mElementType(aElementType) {}
         CModelComponent(const normal_float aAlpha, const std::string &arLabel, const FACE_TYPE aObjType)
-            : mLabel(arLabel), mElementType(aObjType), mClm(), mMaterial() { SetOpacity(aAlpha); }
+            : mLabel(arLabel), mElementType(aObjType), mCmap(), mMaterial() { SetOpacity(aAlpha); }
     public:
-        CModelComponent(const CModelComponent &arModel) : mPoints(arModel.mPoints), mFaces(arModel.mFaces), mLabel(arModel.mLabel), mElementType(arModel.mElementType), mClm(arModel.mClm), mMaterial(arModel.mMaterial) {}
+        CModelComponent(const CModelComponent &arModel) : mPoints(arModel.mPoints), mFaces(arModel.mFaces), mLabel(arModel.mLabel), mElementType(arModel.mElementType), mCmap(arModel.mCmap), mMaterial(arModel.mMaterial) {}
         virtual ~CModelComponent() = default;;
 
         // Operator=
         inline CModelComponent& operator= (const CModelComponent& arModel) { mPoints=arModel.mPoints; mFaces=arModel.mFaces;
-            mLabel=arModel.mLabel; mElementType=arModel.mElementType; mClm=arModel.mClm; mMaterial=arModel.mMaterial; return *this; }
+            mLabel=arModel.mLabel; mElementType=arModel.mElementType; mCmap=arModel.mCmap; mMaterial=arModel.mMaterial; return *this; }
 
         // Getters, Setters
         inline std::vector<CPoint> GetPoints() const { return mPoints; }
@@ -51,7 +51,7 @@ namespace vivid
         inline size_t GetFacesCount() const { return mFaces.size(); }
         inline std::string GetLabel() const { return mLabel; }
         inline normal_float GetOpacity() const { return mMaterial.GetOpacity(); }
-        inline CColorMap GetColorMap() const { return mClm; }
+        inline CColorMap GetColorMap() const { return mCmap; }
         inline const CMaterial& GetMaterial() const { return mMaterial; }
         inline FACE_TYPE GetObjType() const { return mElementType; }
 
@@ -59,9 +59,8 @@ namespace vivid
         inline void SetFaces(std::vector<CFace> &arFaces) { mFaces = arFaces; }
         inline void SetLabel(const std::string &arLabel) { mLabel = arLabel; }
         inline void SetOpacity(normal_float aOpacity) { mMaterial.SetOpacity(aOpacity); }
-        inline void SetColor(const string& arColor) { mClm = CColorMap(arColor); }
-        inline void SetColorMap(const CColorMap& arColorMap) { mClm = arColorMap; }
-        inline void SetColorMap(const PyColorMap& arColorMap) { mClm = arColorMap; }
+        inline void SetColor(const string& arColor) { mCmap = CColorMap(arColor); }
+        inline void SetColorMap(const CColorMap& arColorMap) { mCmap = arColorMap; }
         inline void SetMaterial(const CMaterial& arMaterial) { mMaterial = arMaterial; }
 
         /**
@@ -91,14 +90,25 @@ namespace vivid
          */
         void ScaleMesh(const CPoint &arScaleVec);
 
+        /*
+        * OBJ export. writes arModel to arOutputFilePath
+        * @param[in] arOutputFilePath Path and name for output file
+        * @param[in] WithTexture Whether to include Texture Data or not
+        */
         void ExportToObj(const std::string &arOutputFilePath, bool WithTexture = 1);
 
         /**
-        * Assimp export. writes arModel in aFileType format at aOutputPath
-        * @param[in] aOutputPath Path and name for output file
+        * Assimp export. writes arModel in aFileType format at arOutputFilePath
+        * @param[in] arOutputFilePath Path and name for output file
         * @param[in] aFileType 3D filetype format to write to (out of supported options)
         */
-        int Export(const std::string &arOutputFilePath, const std::string& arFileType = "gltf2");
+        void Export(const std::string &arOutputFilePath, const std::string& arFileType = "gltf2");
+        /**
+        * Assimp export. returns arModel in aFileType format
+        * @param[in] aFileType 3D filetype format to write to (out of supported options)
+        * @returns const void* file blob encoded in provided aFileType
+        */
+        CBlobData ExportToBlob(const std::string& arFileType = "glb");
     };
 };     // namespace vivid
 #endif // VIVID_MODELCOMPONENT_H
\ No newline at end of file
